<?php

class PHP_AES_Cipher {

    private static $OPENSSL_CIPHER_NAME = "aes-128-cbc"; //Name of OpenSSL Cipher 
    private static $CIPHER_KEY_LEN = 16; //128 bits

    /**
     * Encrypt data using AES Cipher (CBC) with 128 bit key
     * 
     * @param type $password - key to use should be 16 bytes long (128 bits)
     * @param type $iv - initialization vector
     * @param type $data - data to encrypt
     * @return encrypted data in base64 encoding with iv attached at end after a :
     */

    static function encrypt($password, $iv, $data) {
        if (strlen($password) < PHP_AES_Cipher::$CIPHER_KEY_LEN) {
            $password = str_pad("$password", PHP_AES_Cipher::$CIPHER_KEY_LEN, "0"); //0 pad to len 16
        } else if (strlen($password) > PHP_AES_Cipher::$CIPHER_KEY_LEN) {
            $password = substr($str, 0, PHP_AES_Cipher::$CIPHER_KEY_LEN); //truncate to 16 bytes
        }
        
        $encodedEncryptedData = base64_encode(openssl_encrypt($data, PHP_AES_Cipher::$OPENSSL_CIPHER_NAME, $password, OPENSSL_RAW_DATA, $iv));
        $encodedIV = base64_encode($iv);
        $encryptedPayload = $encodedEncryptedData.":".$encodedIV;
        
        return $encryptedPayload;
        
    }

    /**
     * Decrypt data using AES Cipher (CBC) with 128 bit key
     * 
     * @param type $password - key to use should be 16 bytes long (128 bits)
     * @param type $data - data to be decrypted in base64 encoding with iv attached at the end after a :
     * @return decrypted data
     */
    static function decrypt($password, $data) {
        if (strlen($password) < PHP_AES_Cipher::$CIPHER_KEY_LEN) {
            $password = str_pad("$password", PHP_AES_Cipher::$CIPHER_KEY_LEN, "0"); //0 pad to len 16
        } else if (strlen($password) > PHP_AES_Cipher::$CIPHER_KEY_LEN) {
            $password = substr($str, 0, PHP_AES_Cipher::$CIPHER_KEY_LEN); //truncate to 16 bytes
        }
        
        $parts = explode(':', $data); //Separate Encrypted data from iv.
        $decryptedData = openssl_decrypt(base64_decode($parts[0]), PHP_AES_Cipher::$OPENSSL_CIPHER_NAME, $password, OPENSSL_RAW_DATA, base64_decode($parts[1]));
        
        return $decryptedData;
    }

}

//Code to Test Class
$iv = 'V3ct0r_$tr1n9K3y'; #Same as in JAVA
$password = 'Pa$$w0rd_4_Pr0xy'; #Same as in JAVA
$data = "Hello World!!!!";

 

$encrypted = PHP_AES_Cipher::encrypt($password, $iv, $data);

echo "Encrypted : $encrypted <br><br>";

 

 

?>